pub struct ElfDebugInfo {
pub data: Vec<u8>,
}Expand description
Debug information for a native ELF binary, packaged as a ZIP with the
DWARF-bearing binary stored as dwarf at the root plus an optional
__source/ bundle — the same layout as AppleDsym.
Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for ElfDebugInfo
impl Clone for ElfDebugInfo
Sourcefn clone(&self) -> ElfDebugInfo
fn clone(&self) -> ElfDebugInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElfDebugInfo
impl Debug for ElfDebugInfo
impl Eq for ElfDebugInfo
Sourceimpl PartialEq for ElfDebugInfo
impl PartialEq for ElfDebugInfo
Sourcefn eq(&self, other: &ElfDebugInfo) -> bool
fn eq(&self, other: &ElfDebugInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ElfDebugInfo